@@ -1,4 +1,4 @@
-#include "polygon.hpp"
+#include "polygon.h"
 #include <cmath>
 
 class triangle : public polygon
